@@ -38,11 +38,3 @@ expect_length <- function(object, n) {
   fail(message)
 }
 
-## -----------------------------------------------------------------------------
-test_that("length computed correctly", {
-  expect_success(expect_length(1, 1))
-  expect_failure(expect_length(1, 2), "has length 1, not length 2.")
-  expect_success(expect_length(1:10, 10))
-  expect_success(expect_length(letters[1:5], 5))
-})
-
